.. _vbelt_model_profile:

V-belts model and profile input data
====================================


V-belt model
------------

.. csv-table:: V-belt model and data entries for module functions
    :header: "Model", "Data entry"
    :widths: 20, 20

    "Super-HC", "`SuperHC`"
    "Hi-Power 2", "`HiPower`"


V-belt profile
--------------

.. csv-table:: V-Belts profiles and data entries for the module functions
    :header: "Model", "Profile", "Data entry"
    :widths: 20, 20, 20

    "Super-HC", "3V", "`3v`"
    "Super-HC", "5V", "`5v`"
    "Super-HC", "8V", "`8v`"
    "Hi-Power 2", "A", "`a`"
    "Hi-Power 2", "B", "`b`"
    "Hi-Power 2", "C", "`c`"
    "Hi-Power 2", "D", "`d`"